# toproxypdf

toproxypdf creates a printable pdf of Magic the Gathering proxies from a folder of images  
The user needs to provie a folder including images and a pdf that while printed on US printer paper(8.5"x 11") can be covered over a 2R MTG card(2.5" * 3.5 ") as a proxy  
More detailed explanations can be seen in [examples](./examples/README.md)

## Installation

With `pip` module you can download toproxypdf with platform-varied versions of  
`pip install toproxypdf`
and an executable will be added to your $PATH

## Usage

`usage: toproxypdf [-h] [-o OUTPUT] [-e EXCLUDED [EXCLUDED ...]] [-d DPI] [-c--corner] [-r REPEAT] [--overwrite] [-v | -q] folder`

## Bug Tracking

Please open an issue over [here](https://github.com/feimaomiao/toproxypdf/issues)

## Contributions

Pull requests are welcome : )  

## Additional Notes

toproxypdf works extremely well with [mpcfill](https://mpcfill.com/)  
Downloading a deck of photos into a folder can then be easily converted into a pdf for you to print at home.

## License

[MIT](https://choosealicense.com/licenses/mit/)
